@@ -14,5 +14,5 @@ class TestDBUtils(unittest.TestCase):
         user_agent = svc_code
         databases = get_db_properties(url, plat_key, svc_code, profile, user_agent)
         for (k, v) in databases.items():
-            print("DSN-N:%s, ip:%s, port:%d, sid:%s, username:%s, password:%s" %
+            print("dsn-n:%s, ip:%s, port:%d, sid:%s, username:%s, password:%s" %
                   (k, v["ip"], v["port"], v["sid"], v["username"], v["password"]))
